import boto
import boto.s3.connection
import boto.sqs
from boto.s3.connection import OrdinaryCallingFormat

from boto.sqs.message import RawMessage

class KeyBucketConnect(object):

    def __init__(self, folder, bucket_name=None, environment='development'):

        # O ideal seria o get_bucket ser um @classmethod, mas nao achei viavel
        # por ter a escolha do bucket baseado no parametro passado. Talvez separar em methodos
        # futuramento. Nao deu nenhum problema ate agora. unattis
        self.s3_conn = boto.connect_s3(calling_format=OrdinaryCallingFormat())
        self.bucket = self.s3_conn.get_bucket(bucket_name)
        self.folder = folder + environment

    def get_key(self, path):
        return self.bucket.get_key(path)

    def set(self, path, string):
        key = self.bucket.new_key(self.folder + path)
        key.set_contents_from_string(string)
        key.set_acl('public-read')

    def set_from_file(self, path, file):
        key = self.bucket.new_key(self.folder + path)
        key.set_contents_from_file(file)
        key.set_acl('public-read')

    def set_from_filename(self, path, file):
        key = self.bucket.new_key(self.folder + path)
        key.set_contents_from_filename(file)
        key.set_acl('public-read')

    def list(self):
        return self.bucket.list(self.folder)

    def delete_key(self, key):
        return self.bucket.delete_key(key)


class SQSConnect(object):
    def __init__(self, region=None):
        self.server = boto.sqs.connect_to_region(region)
    def get_queue(self, queue):
        q = self.server.get_queue(queue)
        q.set_message_class(RawMessage)
        return q


# -*- coding: utf-8 -*-
# ATENCAO: nao chame este arquivo de redis. Vai entrar em conflito com o modulo redis do sistema

import redis
import os

class RedisConnect(object):

    def __init__(self, host=None, port=None, db=None):

        if host is None:
            host = os.environ.get('REDIS_HOST')

        if port is None:
            port = os.environ.get('REDIS_PORT')

        if db is None:
            db = os.environ.get('REDIS_DB')

        self.server = self.set_server(host,port,db)

    @classmethod
    def set_server(self, host, port, db):

        key = '{}:{}/{}'.format(host,port,db)

        if hasattr(self,'pools') is False:
            self.pools = {}
            self.servers = {}

        if key not in self.pools:
            self.pools[key] = redis.ConnectionPool(
                    host=host, port=port, db=db,
                    max_connections=50)

            self.servers[key] = redis.StrictRedis(connection_pool=self.pools[key])

        return self.servers[key]

    def get(self, key):
        return self.server.get(key)

    def set(self, key, value):
        return self.server.set(key, value)

    def setex(self, key, ttl, value):
        return self.server.setex(key, ttl, value)

    def getset(self, key, value):
        return self.server.getset(key, value)

    def expire(self, key, value):
        return self.server.expire(key, value)

    def exists(self, key):
        return self.server.exists(key)

    def delete(self, key):
        return self.server.delete(key)

    def lpush(self, key, value):
        return self.server.lpush(key, value)

    def lpop(self, key):
        return self.server.lpop(key)
